@@ -18,12 +18,12 @@ from sphinx.errors import NoUri
 from docutils import nodes
 from docutils.parsers.rst import directives
 
-from mlx.jira_interaction import create_jira_issues
 from mlx.traceable_attribute import TraceableAttribute
 from mlx.traceable_base_node import TraceableBaseNode
 from mlx.traceable_item import TraceableItem
 from mlx.traceable_collection import TraceableCollection
 from mlx.traceability_exception import TraceabilityException, MultipleTraceabilityExceptions, report_warning
+from mlx.directives.attribute_link_directive import AttributeLink, AttributeLinkDirective
 from mlx.directives.attribute_sort_directive import AttributeSort, AttributeSortDirective
 from mlx.directives.checkbox_result_directive import CheckboxResultDirective
 from mlx.directives.checklist_item_directive import ChecklistItemDirective
@@ -109,21 +109,6 @@ def warn_missing_checklist_items(regex):
                            .format(item_id, item_info.mr_id))
 
 
-def jira_interaction(app):
-    """ Execute the functionality that creates Jira tickets based on traceable items.
-
-    Args:
-        app: Sphinx application object to use.
-    """
-    try:
-        create_jira_issues(app.config.traceability_jira_automation, app.builder.env.traceability_collection)
-    except Exception as err:  # pylint: disable=broad-except
-        if app.config.traceability_jira_automation.get('errors_to_warnings', True):
-            report_warning("Jira interaction failed: {}".format(err))
-        else:
-            raise err
-
-
 # -----------------------------------------------------------------------------
 # Pending item cross reference node
 
@@ -236,9 +221,6 @@ def perform_consistency_check(app, doctree):
     if regex is not None and app.config.traceability_checklist['has_checklist_items']:
         warn_missing_checklist_items(regex)
 
-    if app.config.traceability_jira_automation:
-        jira_interaction(app)
-
 
 def process_item_nodes(app, doctree, fromdocname):
     """
@@ -248,9 +230,19 @@ def process_item_nodes(app, doctree, fromdocname):
     Augment each item with a backlink to the original location.
     """
     env = app.builder.env
-
-    for node_class in (AttributeSort, ItemLink, ItemMatrix, ItemPieChart, ItemAttributesMatrix, Item2DMatrix, ItemList,
-                       ItemTree, ItemAttribute, Item):  # order is important: e.g. AttributeSort before Item
+    node_classes = (
+        AttributeLink,
+        AttributeSort,
+        ItemLink, ItemMatrix,
+        ItemPieChart,
+        ItemAttributesMatrix,
+        Item2DMatrix,
+        ItemList,
+        ItemTree,
+        ItemAttribute,
+        Item,
+    )
+    for node_class in node_classes:  # order is important: e.g. AttributeSort before Item
         for node in doctree.traverse(node_class):
             node.perform_replacement(app, env.traceability_collection)
 
@@ -286,6 +278,7 @@ def init_available_relationships(app):
         ItemAttributesMatrixDirective,
         Item2DMatrixDirective,
         ItemTreeDirective,
+        AttributeLinkDirective,
     )
 
     for attr in app.config.traceability_attributes:
@@ -293,7 +286,7 @@ def init_available_relationships(app):
         for directive_class in directive_classes:
             if attr in directive_class.option_spec:
                 conflicting_directives.append(directive_class.__name__)
-                directive_class.conflicting_options.append(attr)
+                directive_class.conflicting_options.add(attr)
             else:
                 directive_class.option_spec[attr] = directives.unchanged
         define_attribute(attr, app)
@@ -589,9 +582,6 @@ def setup(app):
     # Configuration for notification item about missing items
     app.add_config_value('traceability_notifications', {}, 'env')
 
-    # Configuration for automated issue creation in JIRA
-    app.add_config_value('traceability_jira_automation', {}, 'env')
-
     app.add_node(ItemTree)
     app.add_node(ItemMatrix)
     app.add_node(ItemPieChart)
@@ -613,6 +603,7 @@ def setup(app):
     app.add_directive('item-2d-matrix', Item2DMatrixDirective)
     app.add_directive('item-tree', ItemTreeDirective)
     app.add_directive('item-link', ItemLinkDirective)
+    app.add_directive('attribute-link', AttributeLinkDirective)
     app.add_directive('attribute-sort', AttributeSortDirective)
 
     app.connect('doctree-resolved', process_item_nodes)
